package com.caimei365.manager.controller.wechat;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.caimei365.manager.utils.HttpUtil;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 微信接口调试API
 *
 * @author : Charles
 * @date : 2022/1/12
 */
@RestController
@RequestMapping("/wechat/debug")
public class WechatDebugApi {

    @Value("${wechat.apiUrl}")
    private String wechatApiUrl;

    /**
     * 获取微信 access_token
     */
    @GetMapping("/access_token")
    public String getAccessToken(String appid, String secret) {
        String url = wechatApiUrl + "/cgi-bin/token?grant_type=client_credential&appid=" + appid + "&secret=" + secret;
        return HttpUtil.httpRequest(url, "GET", null);
    }

    /**
     * 获取微信用户列表
     * @param openid 初始openid，不填默认从头开始拉取
     */
    @GetMapping("/user/list")
    public String getUserList(String appid, String secret, String  openid) {
        String tokenUrl = wechatApiUrl + "/cgi-bin/token?grant_type=client_credential&appid=" + appid + "&secret=" + secret;
        String jsonResult = HttpUtil.httpRequest(tokenUrl, "GET", null);
        if(StringUtils.hasLength(jsonResult)){
            JSONObject jsonObject = JSON.parseObject(jsonResult);
            String accessToken = jsonObject.getString("access_token");
            String userUrl = wechatApiUrl + "/cgi-bin/user/get?access_token="+ accessToken + "&next_openid="+ openid;
            return HttpUtil.httpRequest(userUrl, "GET", null);
        }
        return "获取微信用户列表异常";
    }

    /**
     * 公众号迁移后更新OpenId
     */
    @GetMapping("/change/openid")
    public String changeOpenId(String appid, String secret, String json) {
        String tokenUrl = wechatApiUrl + "/cgi-bin/token?grant_type=client_credential&appid=" + appid + "&secret=" + secret;
        String jsonResult = HttpUtil.httpRequest(tokenUrl, "GET", null);
        if(StringUtils.hasLength(jsonResult)){
            JSONObject jsonObject = JSON.parseObject(jsonResult);
            String accessToken = jsonObject.getString("access_token");
            String changeUrl = wechatApiUrl + "/cgi-bin/changeopenid?access_token=?access_token="+ accessToken;
            return HttpUtil.httpRequest(changeUrl, "POST", json);
        }
        return "公众号迁移后更新OpenId异常";
    }
}
